"use strict";
/*!
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
function extractPackageIdentifierDetails(codeDetailsPackage) {
    const packageString = typeof codeDetailsPackage === "string"
        ? codeDetailsPackage // Just return it if it's a string e.g. "@fluid-example/clicker@0.1.1"
        // If it doesn't exist, let's make it from the package details
        : typeof codeDetailsPackage.version === "string"
            ? `${codeDetailsPackage.name}` // E.g. @fluid-example/clicker
            : `${codeDetailsPackage.name}@${codeDetailsPackage.version}`; // Rebuild e.g. @fluid-example/clicker@0.1.1
    let fullId;
    let scope;
    let nameAndVersion;
    let name;
    let version;
    // Two @ symbols === the package has a version. Use alternative RegEx.
    if (packageString.indexOf("@") !== packageString.lastIndexOf("@")) {
        // eslint-disable-next-line @typescript-eslint/prefer-regexp-exec,unicorn/no-unsafe-regex
        const componentsWithVersion = packageString.match(/(@(.*)\/)?((.*)@(.*))/);
        // eslint-disable-next-line no-null/no-null
        if ((componentsWithVersion === null || componentsWithVersion.length !== 6)) {
            throw new Error("Invalid package");
        }
        [fullId, , scope, nameAndVersion, name, version] = componentsWithVersion;
    }
    else {
        // eslint-disable-next-line @typescript-eslint/prefer-regexp-exec,unicorn/no-unsafe-regex
        const componentsWithoutVersion = packageString.match(/(@(.*)\/)?((.*))/);
        // eslint-disable-next-line no-null/no-null
        if ((componentsWithoutVersion === null || componentsWithoutVersion.length !== 5)) {
            throw new Error("Invalid package");
        }
        [fullId, , scope, nameAndVersion, name] = componentsWithoutVersion;
    }
    return {
        fullId,
        name,
        nameAndVersion,
        scope,
        version,
    };
}
exports.extractPackageIdentifierDetails = extractPackageIdentifierDetails;
function resolveFluidPackageEnvironment(environment, baseUrl) {
    const resolvedEnvironment = {};
    for (const targetName of Object.keys(environment)) {
        const target = environment[targetName];
        if (target !== undefined) {
            const files = [];
            for (const file of target.files) {
                if (!file.startsWith("http")) {
                    files.push(`${baseUrl}/${file}`);
                }
                else {
                    files.push(file);
                }
            }
            resolvedEnvironment[targetName] = {
                files,
                library: target.library,
            };
        }
    }
    return resolvedEnvironment;
}
exports.resolveFluidPackageEnvironment = resolveFluidPackageEnvironment;
//# sourceMappingURL=utils.js.map